@@ -6,6 +6,7 @@ __author__ = 'stanislav bashkirtsev'
 
 
 class ScriptSettings:
+  SCRIPT_TEMD_DIR = '/tmp/jtalks-cicd/'
   SCRIPT_WORK_DIR = "" + os.path.expanduser("~/.jtalks/")
   BACKUPS_DIR = SCRIPT_WORK_DIR + "backups/"
   ENV_CONFIGS_DIR = SCRIPT_WORK_DIR + "environments/"
@@ -44,6 +45,12 @@ class ScriptSettings:
     """
     return self.__get_property('app', 'final_name')
 
+  def get_temp_dir(self):
+    """
+     Script can save there some temp files.
+    """
+    return self.SCRIPT_TEMD_DIR
+
   def get_tomcat_port(self):
     """
       This is not actually a pre-configured parameter, it parses $TOMCAT_HOME/conf/server.xml to find out the HTTP
